@@ -9,14 +9,14 @@ from keypartx.basemodes.text_edges import text2edges, opi_verbs,neg_words,nounDE
 import pandas as pd 
 import math, matplotlib
 from itertools import cycle, islice
-from keypartx.basemodes.avn_base import coreNLP
+from keypartx.basemodes.avn_base import nlp
+
 
-nlp = coreNLP()
 
 
 ## -- avnn edges-- ##
 def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL):
-
+    
     time_start = time.time()
     all_adjV2N_edges = []
     allNNedges = [] # noun to noun is the noun in adjV2N 
