@@ -4,13 +4,13 @@ import re ,spacy
 
 #import coreferee
 
-
 def coreNLP():
-  nlp = spacy.load('en_core_web_lg')
+  nlp = spacy.load('en_core_web_lg') #"en_core_web_sm"
   try:
     nlp.add_pipe('coreferee')
+    print('Coreference is Available')
   except:
-    print('Coreference is not available, if needed please install "coreferee" and import separately!!!')
+    print('Coreference is NOT available, otherwise install "coreferee" and import separately before install "keypartx"!!!')
   return nlp 
 
 nlp = coreNLP()
