@@ -23,7 +23,7 @@ neg_words = ['hardly', 'scarcely','barely','no','not','none','neither','nor','ne
 #textneg = "I do not like you never know it be not really pretty, it means no money no girl, I hardly learn in the never nice school"
 #text =""" I don't like this High-quality hotel, /the\ restaraunt food is so ugly and expensive, United states of America next time we will go to New York, "good-good"  the place called "long islands",but I never hate it, it was not pretty,so I don't recommend it."""
 
-nounDEL = ['thing','things','issues','issue','parts','part','lots','lot','years','weeks','months',"hours",'date','hour','minute','year','week','month',"minutes","ones","one"]
+nounDEL = ['thing', 'things','issue', 'issues', 'part', 'parts','lot','lots', 'year', 'years', 'week', 'weeks', 'month','months', 'hour','hours', 'date', 'minute',  'minutes', 'one','ones']
 adjDEL =["same","similar","different","another","other","half", "some", "several", "much", "all", "many", "whole","enough", "little", "sufficient", "most","least","few", "own","very","this", "that", "these", "those","each", "every","any","less","more","only",'next','previous','least','first','second','third','able','last','such','main','really','late','early','possible','due',] # number are deleted separtely 
 #timedate = timedate0 + non_opi_adjs
 #timedate.remove('pengy')
